@@ -6,8 +6,10 @@ pub use tracer::Tracer;
 mod trace;
 pub use trace::Trace;
 
-// reexport the filter object
+// re-export the filter object
 pub use tracing_subscriber::EnvFilter;
+// re-export the subscriber extensions so `collector.init()` can be called explicitly
+pub use tracing_subscriber::util::SubscriberInitExt;
 
 // export the trace listener utils
 mod utils;
