@@ -1,7 +1,7 @@
 // the Tracer trait
 pub trait Tracer: Send + Sync {
     fn name(&self) -> &str;
-    fn child(&self, child_name: &str) -> Box<dyn Tracer>;
+    // fn child(&self, child_name: &'static str) -> Box<dyn Tracer>;
 
     fn trace(&self, message: &str) -> &dyn Tracer;
     fn info(&self, message: &str) -> &dyn Tracer;
