@@ -1,4 +1,4 @@
-use tracing::Level;
+use tracing::{Level, Subscriber};
 use std::io::{stdout, Write};
 use tracing_subscriber::{self, EnvFilter};
 
@@ -50,7 +50,7 @@ impl TraceListenerOptions {
 
 pub fn create_trace_listener(
     options: TraceListenerOptions,
-) {
+) -> Box<dyn Subscriber + Send + Sync> {
     // get the file path and stdout options
     let TraceListenerOptions {
         file_path,
@@ -59,7 +59,7 @@ pub fn create_trace_listener(
         ..
     } = options;
 
-    let _collector = tracing_subscriber::fmt()
+    let collector = tracing_subscriber::fmt()
         // make sure the tracing level filtering is respected
         .with_max_level(options.level)
         // otherwise the log line will always contain trace::trace
@@ -93,5 +93,7 @@ pub fn create_trace_listener(
             return composite_writer;
         })
         .with_env_filter(filter)
-        .init();
+        .finish();
+
+    return Box::new(collector);
 }
